summaryrefslogtreecommitdiff
path: root/tests/gem_lut_handle.c
diff options
context:
space:
mode:
authorThomas Wood <thomas.wood@intel.com>2014-11-28 11:02:44 +0000
committerThomas Wood <thomas.wood@intel.com>2014-12-04 16:07:55 +0000
commitb2ac2642a9b5448761086bdb8ae1a1e2974b3995 (patch)
tree48c6e835a0b62de686a6889847c3176cd77637fe /tests/gem_lut_handle.c
parent029dee797965357dbcbe5a097731701e4d965d82 (diff)
tests: add more test descriptions
Add more test descriptions based on exiting comments. Signed-off-by: Thomas Wood <thomas.wood@intel.com>
Diffstat (limited to 'tests/gem_lut_handle.c')
-rw-r--r--tests/gem_lut_handle.c5
1 files changed, 4 insertions, 1 deletions
diff --git a/tests/gem_lut_handle.c b/tests/gem_lut_handle.c
index d3f6f732..7fc72f1a 100644
--- a/tests/gem_lut_handle.c
+++ b/tests/gem_lut_handle.c
@@ -25,7 +25,7 @@
*
*/
/* Exercises the basic execbuffer using theh andle LUT interface */
#include <stdlib.h>
#include <stdio.h>
@@ -39,6 +39,9 @@
#include "ioctl_wrappers.h"
#include "drmtest.h"
+IGT_TEST_DESCRIPTION("Exercises the basic execbuffer using the handle LUT"
+ " interface.");
+
#define BATCH_SIZE (1024*1024)
#define LOCAL_I915_EXEC_HANDLE_LUT (1<<12)
@@ -25,7 +25,7 @@
*
*/
-/* Exercises the basic execbuffer using theh andle LUT interface */
+/* Exercises the basic execbuffer using the handle LUT interface */
#include <stdlib.h>
#include <stdio.h>